The data were simulated from a 3-latent class linear mixed model. Repeated data for 100 subjects were simulated. The three latent classes are predicted by X2 and X3. In each latent class, Y follows a linear mixed model including intercept and time both with correlated random-effects and class-specific fixed effects. In addition, X1 and X1*time have a common impact over classes on the Y trajectory.
data_hlmeA data frame with 326 observations on the following 9 variables.
IDsubject identification number
Ylongitudinal outcome
Timetime of measurement
X1binary covariate
X2binary covariate
X3binary covariate