hlme, lcmm or Jointlcmm objecthlme, lcmm or Jointlcmm estimation: model specification and goodness-of-fit statistics.## S3 method for class 'hlme':
print(x,\dots)
## S3 method for class 'Jointlcmm':
print(x,\dots)
## S3 method for class 'lcmm':
print(x,\dots)hlme, lcmm or Jointlcmm representing a fitted latent class mixed-effects model or a Joint latent class mixed model.hlme, Jointlcmm, lcmm,