VarCovRE:
Estimates, standard errors and Wald test for the parameters of the variance-covariance matrix of the random effects.
Description
Fromm the Cholesky transformed parameters, this function provides estimates, standard errors and Wald test for the parameters of the variance-covariance matrix of the random effects.
an object of class hlme, lcmm, multlcmm or Jointlcmm
Value
a matrix containing the estimates of the parameters of the variance-covariance matrix of the random effects, their standard errors, and, for the covariance parameters,
the Wald statistic and the associated p-value.