Learn R Programming

lcmm (version 1.7.5)

data_hlme: Simulated dataset for hlme function

Description

The data were simulated from a 3-latent class linear mixed model. Repeated data for 100 subjects were simulated. The three latent classes are predicted by X2 and X3. In each latent class, Y follows a linear mixed model including intercept and time both with correlated random-effects and class-specific fixed effects. In addition, X1 and X1*time have a common impact over classes on the Y trajectory.

Usage

data_hlme

Arguments

Format

A data frame with 326 observations on the following 9 variables.
ID
subject identification number
Y
longitudinal outcome
Time
time of measurement
X1
binary covariate
X2
binary covariate
X3
binary covariate

See Also

hlme, postprob, summary.lcmm, plot.predict