lcmm, Jointlcmm or multlcmm objectsThe function computes the marginal predictions of the longitudinal outcome(s) in their
natural scale on the individual data used for the estimation from lcmm, Jointlcmm or multlcmm objects.
# S3 method for lcmm
fitY(x)
# S3 method for multlcmm
fitY(x)
# S3 method for Jointlcmm
fitY(x)an object inheriting from classes lcmm or multlcmm.
For lcmm and Jointlcmm objects, returns a matrix with ng+1 columns
containing the subject identifier and the ng class-specific marginal predicted
values.
For multlcmm objects, returns a matrix with ng+2 columns
containing the subject identifier, the outcome indicator and the ng
class-specific predicted values.