lcmm, Jointlcmm or multlcmm objectslcmm, Jointlcmm or multlcmm objects.## S3 method for class 'lcmm':
fitY(x)
## S3 method for class 'multlcmm':
fitY(x)
## S3 method for class 'Jointlcmm':
fitY(x)lcmm or multlcmm.lcmm and Jointlcmm objects, returns a matrix with ng+1 columns
containing the subject identifier and the ng class-specific marginal predicted
values.
For multlcmm objects, returns a matrix with ng+2 columns
containing the subject identifier, the outcome indicator and the ng
class-specific predicted values.predictY, plot.lcmm