The dataset consists in a subsample of the Paquid prospective cohort study. Repeated measures cognitive measures (MMSE, IST, BVRT psychometric tests), physical dependency (HIER) and depression sympatomatology (CESD) were collected over a maximum period of 20 years along with dementia information (age at dementia diagnosis, dementia diagnosis information). Time-independent socio-demographic information is also provided (CEP, male, age_init).
paquidA data frame with 2250 observations over 500 subjects and 12 variables:
IDsubject identification number
MMSEscore at the Mini-Mental State Examination (MMSE), a psychometric test of global cognitive functioning (integer in range 0-30)
BVRTscore at the Benton Visual Retention Test (BVRT), a psychometric test of spatial memory (integer in range 0-15)
ISTscore at the Isaacs Set Test (IST) truncated at 15 seconds, a test of verbal memory (integer in range 0-40)
HIERscore of physical dependency (0=no dependency, 1=mild dependency, 2=moderate dependency, 3=severe dependency)
CESDscore of a short self-report scale CES-D designed to measure depressive symptomatology in the general population (integer in range 0-52)
ageage at the follow-up visit
demindicator of positive diagnosis of dementia
agedemage at dementia diagnosis for dem=1 and at last contact for dem=0
age_initage at entry in the cohort
CEPbinary indicator of educational level (CEP=1 for subjects who graduated from primary school; CEP=0 otherwise)
malebinary indicator for gender (male=1 for men; male=0 for women)
Letenneur, L., Commenges, D., Dartigues, J. F., & Barberger-Gateau, P. (1994). Incidence of dementia and Alzheimer's disease in elderly community residents of southwestern France. International Journal of Epidemiology, 23 (6), 1256-61.
# NOT RUN {
summary(paquid)
# }
Run the code above in your browser using DataLab