Prediction of the Brownian motion or the autoregressive correlation
Source:R/predictCor.R
predictCor.RdThe function computes the predicted values of the BM or AR correlation given observed data provided in input.
Arguments
- model
an object inheriting from class
hlme,lcmm,Jointlcmmormultlcmmrepresenting a general latent class mixed model.- newdata
data frame containing the data from which predictions are to be computed. The data frame should include at least all the covariates listed in model$Xnames2, and the marker(s) values. Names should match exactly the names of the variables in the model.
- predtimes
numeric vector containing the prediction times