hlme, lcmm or Jointlcmm objecthlme, lcmm or Jointlcmm estimation: model specification, goodness-of-fit statistics, maximum likelihood estimates and associated Wald test.## S3 method for class 'hlme':
summary(object,\dots)
## S3 method for class 'lcmm':
summary(object,\dots)
## S3 method for class 'Jointlcmm':
summary(object,\dots)hlme, lcmm or Jointlcmm representing a fitted latent class mixed-effects model or a Joint latent class mixed model.hlme, lcmm, Jointlcmm,